@@ -136,7 +136,7 @@ class Checkpoint:
         if isinstance(runtime_kwargs_batch_request, BatchRequest):
             runtime_kwargs[
                 "batch_request"
-            ] = runtime_kwargs_batch_request.to_json_dict()
+            ] = runtime_kwargs_batch_request.get_json_dict()
 
         substituted_config: Union[CheckpointConfig, dict]
         if (
