@@ -3,12 +3,14 @@ from great_expectations.datasource.data_connector import (
     ConfiguredAssetAzureDataConnector,
     ConfiguredAssetFilePathDataConnector,
     ConfiguredAssetFilesystemDataConnector,
+    ConfiguredAssetGCSDataConnector,
     ConfiguredAssetS3DataConnector,
     ConfiguredAssetSqlDataConnector,
     DataConnector,
     FilePathDataConnector,
     InferredAssetFilePathDataConnector,
     InferredAssetFilesystemDataConnector,
+    InferredAssetGCSDataConnector,
     InferredAssetS3DataConnector,
     InferredAssetSqlDataConnector,
     RuntimeDataConnector,
@@ -22,10 +24,12 @@ class DataConnectorAnonymizer(Anonymizer):
         # This list should contain all DataConnector types. When new DataConnector types
         # are created, please make sure to add ordered bottom up in terms of inheritance order
         self._ge_classes = [
+            InferredAssetGCSDataConnector,
             InferredAssetS3DataConnector,
             InferredAssetFilesystemDataConnector,
             InferredAssetFilePathDataConnector,
             InferredAssetSqlDataConnector,
+            ConfiguredAssetGCSDataConnector,
             ConfiguredAssetS3DataConnector,
             ConfiguredAssetAzureDataConnector,
             ConfiguredAssetFilesystemDataConnector,
@@ -37,7 +41,7 @@ class DataConnectorAnonymizer(Anonymizer):
         ]
 
     def anonymize_data_connector_info(self, name, config):
-        anonymized_info_dict = dict()
+        anonymized_info_dict = {}
         anonymized_info_dict["anonymized_name"] = self.anonymize(name)
 
         self.anonymize_object_info(
