@@ -3,6 +3,7 @@ import datetime
 import decimal
 import logging
 import os
+import re
 import sys
 import uuid
 from collections import OrderedDict
@@ -403,6 +404,32 @@ def datetime_to_int(dt: datetime.date) -> int:
     return int(dt.strftime("%Y%m%d%H%M%S"))
 
 
+class AzureUrl:
+    """
+    Parses an Azure Blob Storage URL into its separate components
+    """
+
+    def __init__(self, url: str):
+        search = re.search(
+            r"^(?:https?://)?(.+?).blob.core.windows.net/([^/]+)/(.+)$", url
+        )
+        self._account_name = search.group(1)
+        self._container = search.group(2)
+        self._blob = search.group(3)
+
+    @property
+    def account_name(self):
+        return self._account_name
+
+    @property
+    def container(self):
+        return self._container
+
+    @property
+    def blob(self):
+        return self._blob
+
+
 # S3Url class courtesy: https://stackoverflow.com/questions/42641315/s3-urls-get-bucket-name-and-path
 class S3Url:
     """
