@@ -201,7 +201,7 @@ class ExpectationsStore(Store):
             key=test_key,
         )
         if pretty_print:
-            print("\tTest value successfully retreived.")
+            print("\tTest value successfully retrieved.")
             print()
 
         if pretty_print:
