@@ -292,12 +292,16 @@ class DataConnectorConfig(DictDot):
         # S3
         boto3_options=None,
         bucket=None,
-        prefix=None,
         max_keys=None,
         # Azure
         azure_options=None,
         container=None,
         name_starts_with=None,
+        # GCS
+        bucket_or_name=None,
+        max_results=None,
+        # Both S3/GCS
+        prefix=None,
         # Both S3/Azure
         delimiter=None,
         **kwargs,
@@ -326,8 +330,6 @@ class DataConnectorConfig(DictDot):
             self.boto3_options = boto3_options
         if bucket is not None:
             self.bucket = bucket
-        if prefix is not None:
-            self.prefix = prefix
         if max_keys is not None:
             self.max_keys = max_keys
 
@@ -339,6 +341,16 @@ class DataConnectorConfig(DictDot):
         if name_starts_with is not None:
             self.name_starts_with = name_starts_with
 
+        # GCS
+        if bucket_or_name is not None:
+            self.bucket_or_name = bucket_or_name
+        if max_results is not None:
+            self.max_results = max_results
+
+        # Both S3/GCS
+        if prefix is not None:
+            self.prefix = prefix
+
         # Both S3/Azure
         if delimiter is not None:
             self.delimiter = delimiter
@@ -387,7 +399,6 @@ class DataConnectorConfigSchema(Schema):
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
     bucket = fields.String(required=False, allow_none=True)
-    prefix = fields.String(required=False, allow_none=True)
     max_keys = fields.Integer(required=False, allow_none=True)
 
     # Azure
@@ -397,6 +408,16 @@ class DataConnectorConfigSchema(Schema):
     container = fields.String(required=False, allow_none=True)
     name_starts_with = fields.String(required=False, allow_none=True)
 
+    # GCS
+    gcs_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
+    bucket_or_name = fields.String(required=False, allow_none=True)
+    max_results = fields.String(required=False, allow_none=True)
+
+    # Both S3/GCS
+    prefix = fields.String(required=False, allow_none=True)
+
     # Both S3/Azure
     delimiter = fields.String(required=False, allow_none=True)
 
@@ -430,10 +451,12 @@ class DataConnectorConfigSchema(Schema):
                 "ConfiguredAssetS3DataConnector",
                 "InferredAssetAzureDataConnector",
                 "ConfiguredAssetAzureDataConnector",
+                "InferredAssetGCSDataConnector",
+                "ConfiguredAssetGCSDataConnector",
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by a
+                f"""Your current configuration uses one or more keys in a data connector that are required only by a
 subclass of the FilePathDataConnector class (your data connector is "{data['class_name']}").  Please update your
 configuration to continue.
                 """
@@ -446,7 +469,7 @@ configuration to continue.
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by a
+                f"""Your current configuration uses one or more keys in a data connector that are required only by a
 filesystem type of the data connector (your data connector is "{data['class_name']}").  Please update your
 configuration to continue.
                 """
@@ -461,8 +484,23 @@ configuration to continue.
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+                f"""Your current configuration uses one or more keys in a data connector that are required only by an
 S3/Azure type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
+continue.
+                """
+            )
+        if ("prefix" in data) and not (
+            data["class_name"]
+            in [
+                "InferredAssetS3DataConnector",
+                "ConfiguredAssetS3DataConnector",
+                "InferredAssetGCSDataConnector",
+                "ConfiguredAssetGCSDataConnector",
+            ]
+        ):
+            raise ge_exceptions.InvalidConfigError(
+                f"""Your current configuration uses one or more keys in a data connector that are required only by an
+S3/GCS type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                 """
             )
@@ -474,7 +512,7 @@ continue.
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+                f"""Your current configuration uses one or more keys in a data connector that are required only by an
 S3 type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                 """
@@ -489,7 +527,7 @@ continue.
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+                f"""Your current configuration uses one or more keys in a data connector that are required only by an
 Azure type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                     """
@@ -505,6 +543,32 @@ continue.
                     You must only select one between `conn_str` and `account_url`. Please update your configuration to continue.
                     """
                 )
+        if (
+            "gcs_options" in data or "bucket_or_name" in data or "max_results" in data
+        ) and not (
+            data["class_name"]
+            in [
+                "InferredAssetGCSDataConnector",
+                "ConfiguredAssetGCSDataConnector",
+            ]
+        ):
+            raise ge_exceptions.InvalidConfigError(
+                f"""Your current configuration uses one or more keys in a data connector that are required only by a
+GCS type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
+continue.
+                    """
+            )
+        if "gcs_options" in data and data["class_name"] in [
+            "InferredAssetGCSDataConnector",
+            "ConfiguredAssetGCSDataConnector",
+        ]:
+            gcs_options = data["gcs_options"]
+            if "filename" in gcs_options and "info" in gcs_options:
+                raise ge_exceptions.InvalidConfigError(
+                    f"""Your current configuration can only use a single method of authentication for the GCS type of data connector.
+                    You must only select one between `filename` (from_service_account_file) and `info` (from_service_account_info). Please update your configuration to continue.
+                    """
+                )
         if (
             "data_asset_name_prefix" in data
             or "data_asset_name_suffix" in data
@@ -524,7 +588,7 @@ continue.
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data connector, that are required only by an
+                f"""Your current configuration uses one or more keys in a data connector that are required only by an
 SQL type of the data connector (your data connector is "{data['class_name']}").  Please update your configuration to
 continue.
                 """
@@ -548,6 +612,7 @@ class ExecutionEngineConfig(DictDot):
         spark_config=None,
         boto3_options=None,
         azure_options=None,
+        gcs_options=None,
         **kwargs,
     ):
         self._class_name = class_name
@@ -566,6 +631,8 @@ class ExecutionEngineConfig(DictDot):
             self.boto3_options = boto3_options
         if azure_options is not None:
             self.azure_options = azure_options
+        if gcs_options is not None:
+            self.gcs_options = gcs_options
         for k, v in kwargs.items():
             setattr(self, k, v)
 
@@ -597,6 +664,9 @@ class ExecutionEngineConfigSchema(Schema):
     azure_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
+    gcs_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
     caching = fields.Boolean(required=False, allow_none=True)
     batch_spec_defaults = fields.Dict(required=False, allow_none=True)
 
@@ -645,6 +715,7 @@ class DatasourceConfig(DictDot):
         tables=None,
         boto3_options=None,
         azure_options=None,
+        gcs_options=None,
         reader_method=None,
         reader_options=None,
         limit=None,
@@ -691,6 +762,8 @@ class DatasourceConfig(DictDot):
             self.boto3_options = boto3_options
         if azure_options is not None:
             self.azure_options = azure_options
+        if gcs_options is not None:
+            self.gcs_options = gcs_options
         if reader_method is not None:
             self.reader_method = reader_method
         if reader_options is not None:
@@ -743,6 +816,9 @@ class DatasourceConfigSchema(Schema):
     azure_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
     )
+    gcs_options = fields.Dict(
+        keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
+    )
     reader_method = fields.String(required=False, allow_none=True)
     reader_options = fields.Dict(
         keys=fields.Str(), values=fields.Str(), required=False, allow_none=True
@@ -754,7 +830,7 @@ class DatasourceConfigSchema(Schema):
         if "generators" in data:
             raise ge_exceptions.InvalidConfigError(
                 'Your current configuration uses the "generators" key in a datasource, but in version 0.10 of '
-                'GE, that key is renamed to "batch_kwargs_generators". Please update your configuration to continue.'
+                'GE that key is renamed to "batch_kwargs_generators". Please update your configuration to continue.'
             )
         # If a class_name begins with the dollar sign ("$"), then it is assumed to be a variable name to be substituted.
         if data["class_name"][0] == "$":
@@ -772,7 +848,7 @@ class DatasourceConfigSchema(Schema):
             ]
         ):
             raise ge_exceptions.InvalidConfigError(
-                f"""Your current configuration uses one or more keys in a data source, that are required only by a
+                f"""Your current configuration uses one or more keys in a data source that are required only by a
 sqlalchemy data source (your data source is "{data['class_name']}").  Please update your configuration to continue.
                 """
             )
