@@ -4,6 +4,7 @@ from .configured_asset_file_path_data_connector import (
 from .configured_asset_filesystem_data_connector import (
     ConfiguredAssetFilesystemDataConnector,
 )
+from .configured_asset_gcs_data_connector import ConfiguredAssetGCSDataConnector
 from .configured_asset_s3_data_connector import ConfiguredAssetS3DataConnector
 from .configured_asset_sql_data_connector import ConfiguredAssetSqlDataConnector
 from .data_connector import DataConnector
@@ -12,6 +13,7 @@ from .inferred_asset_file_path_data_connector import InferredAssetFilePathDataCo
 from .inferred_asset_filesystem_data_connector import (
     InferredAssetFilesystemDataConnector,
 )
+from .inferred_asset_gcs_data_connector import InferredAssetGCSDataConnector
 from .inferred_asset_s3_data_connector import InferredAssetS3DataConnector
 from .inferred_asset_sql_data_connector import InferredAssetSqlDataConnector
 from .runtime_data_connector import RuntimeDataConnector
