@@ -9,14 +9,6 @@ import sre_parse
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Union
 
-from azure.core.paging import ItemPaged
-from azure.storage.blob import (
-    BlobPrefix,
-    BlobProperties,
-    BlobServiceClient,
-    ContainerClient,
-)
-
 from great_expectations.core.batch import BatchDefinition, BatchRequestBase
 from great_expectations.core.id_dict import IDDict
 from great_expectations.data_context.util import instantiate_class_from_config
@@ -24,6 +16,16 @@ from great_expectations.datasource.data_connector.sorter import Sorter
 
 logger = logging.getLogger(__name__)
 
+try:
+    from azure.storage.blob import BlobPrefix, BlobServiceClient, ContainerClient
+except ImportError:
+    BlobPrefix = None
+    BlobServiceClient = None
+    ContainerClient = None
+    logger.debug(
+        "Unable to load azure types; install optional azure dependency for support."
+    )
+
 try:
     import pyspark
     import pyspark.sql as pyspark_sql
