@@ -3,6 +3,7 @@ import datetime
 import hashlib
 import logging
 import uuid
+import warnings
 from functools import reduce
 from typing import Any, Callable, Dict, Iterable, Optional, Tuple, Union
 
@@ -390,11 +391,19 @@ Please check your config."""
                 )
                 data = data.filter(~ignore_condition)
             else:
-                if ignore_row_if != "never":
+                if ignore_row_if not in ["neither", "never"]:
                     raise ValueError(
                         f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
                     )
 
+                if ignore_row_if == "never":
+                    warnings.warn(
+                        f"""The correct "no-action" value of the "ignore_row_if" directive for the column pair case is \
+"neither" (the use of "{ignore_row_if}" will be deprecated).  Please update code accordingly.
+""",
+                        DeprecationWarning,
+                    )
+
             return data
 
         if "column_list" in domain_kwargs and "ignore_row_if" in domain_kwargs:
@@ -455,7 +464,7 @@ Please check your config."""
         domain_type = MetricDomainTypes(domain_type)
 
         compute_domain_kwargs = copy.deepcopy(domain_kwargs)
-        accessor_domain_kwargs = dict()
+        accessor_domain_kwargs = {}
         table = domain_kwargs.get("table", None)
         if table:
             raise ValueError(
@@ -580,8 +589,8 @@ Please check your config."""
                 Returns:
                     A dictionary of the collected metrics over their respective domains
         """
-        resolved_metrics = dict()
-        aggregates: Dict[Tuple, dict] = dict()
+        resolved_metrics = {}
+        aggregates: Dict[Tuple, dict] = {}
         for (
             metric_to_resolve,
             engine_fn,
