@@ -2,6 +2,7 @@ import copy
 import datetime
 import logging
 import traceback
+import warnings
 from pathlib import Path
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 from urllib.parse import urlparse
@@ -85,10 +86,20 @@ except (ImportError, KeyError, AttributeError):
 try:
     import pybigquery.sqlalchemy_bigquery
 
-    # Sometimes "pybigquery.sqlalchemy_bigquery" fails to self-register in certain environments, so we do it explicitly.
+    ###
+    # NOTE: 20210816 - jdimatteo: A convention we rely on is for SqlAlchemy dialects
+    # to define an attribute "dialect". A PR has been submitted to fix this upstream
+    # with https://github.com/googleapis/python-bigquery-sqlalchemy/pull/251. If that
+    # fix isn't present, add this "dialect" attribute here:
+    if not hasattr(pybigquery.sqlalchemy_bigquery, "dialect"):
+        pybigquery.sqlalchemy_bigquery.dialect = (
+            pybigquery.sqlalchemy_bigquery.BigQueryDialect
+        )
+
+    # Sometimes "pybigquery.sqlalchemy_bigquery" fails to self-register in Azure (our CI/CD pipeline) in certain cases, so we do it explicitly.
     # (see https://stackoverflow.com/questions/53284762/nosuchmoduleerror-cant-load-plugin-sqlalchemy-dialectssnowflake)
     sa.dialects.registry.register(
-        "bigquery", "pybigquery.sqlalchemy_bigquery", "BigQueryDialect"
+        "bigquery", "pybigquery.sqlalchemy_bigquery", "dialect"
     )
     try:
         getattr(pybigquery.sqlalchemy_bigquery, "INTEGER")
@@ -488,11 +499,19 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
                     )
                 )
             else:
-                if ignore_row_if != "never":
+                if ignore_row_if not in ["neither", "never"]:
                     raise ValueError(
                         f'Unrecognized value of ignore_row_if ("{ignore_row_if}").'
                     )
 
+                if ignore_row_if == "never":
+                    warnings.warn(
+                        f"""The correct "no-action" value of the "ignore_row_if" directive for the column pair case is \
+"neither" (the use of "{ignore_row_if}" will be deprecated).  Please update code accordingly.
+""",
+                        DeprecationWarning,
+                    )
+
             return selectable
 
         if "column_list" in domain_kwargs and "ignore_row_if" in domain_kwargs:
@@ -583,7 +602,7 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             )
 
         compute_domain_kwargs = copy.deepcopy(domain_kwargs)
-        accessor_domain_kwargs = dict()
+        accessor_domain_kwargs = {}
         if domain_type == MetricDomainTypes.TABLE:
             if accessor_keys is not None and len(list(accessor_keys)) > 0:
                 for key in accessor_keys:
@@ -689,10 +708,10 @@ class SqlAlchemyExecutionEngine(ExecutionEngine):
             Returns:
                 A dictionary of metric names and their corresponding now-queried values.
         """
-        resolved_metrics = dict()
+        resolved_metrics = {}
 
         # We need a different query for each domain (where clause).
-        queries: Dict[Tuple, dict] = dict()
+        queries: Dict[Tuple, dict] = {}
         for (
             metric_to_resolve,
             engine_fn,
