@@ -223,7 +223,7 @@ def infer_distribution_parameters(data, distribution, params=None):
     """
 
     if params is None:
-        params = dict()
+        params = {}
     elif not isinstance(params, dict):
         raise TypeError(
             "params must be a dictionary object, see great_expectations documentation"
