@@ -1,14 +1,6 @@
-from typing import Dict, Optional
+from typing import Optional
 
-from dateutil.parser import parse
-
-from great_expectations.core.batch import Batch
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
-from great_expectations.execution_engine import (
-    ExecutionEngine,
-    PandasExecutionEngine,
-    SparkDFExecutionEngine,
-)
 from great_expectations.expectations.util import render_evaluation_parameter_string
 
 from ...render.renderer.renderer import renderer
@@ -18,10 +10,10 @@ from ...render.util import (
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import InvalidExpectationConfigurationError, TableExpectation
+from ..expectation import ColumnPairMapExpectation, InvalidExpectationConfigurationError
 
 
-class ExpectColumnPairValuesAToBeGreaterThanB(TableExpectation):
+class ExpectColumnPairValuesAToBeGreaterThanB(ColumnPairMapExpectation):
     """
     Expect values in column A to be greater than column B.
 
@@ -40,23 +32,15 @@ class ExpectColumnPairValuesAToBeGreaterThanB(TableExpectation):
     Other Parameters:
         result_format (str or None): \
             Which output mode to use: `BOOLEAN_ONLY`, `BASIC`, `COMPLETE`, or `SUMMARY`.
-            For more detail, see :ref:`result_format <result_format>`.
         include_config (boolean): \
             If True, then include the expectation config as part of the result object. \
-            For more detail, see :ref:`include_config`.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
-            For more detail, see :ref:`catch_exceptions`.
         meta (dict or None): \
-            A JSON-serializable dictionary (nesting allowed) that will be included in the output without \
-            modification. For more detail, see :ref:`meta`.
+            A JSON-serializable dictionary (nesting allowed) that will be included in the output without modification.
 
     Returns:
         An ExpectationSuiteValidationResult
-
-        Exact fields vary depending on the values passed to :ref:`result_format <result_format>` and
-        :ref:`include_config`, :ref:`catch_exceptions`, and :ref:`meta`.
-
     """
 
     # This dictionary contains metadata for display in the public gallery
@@ -72,7 +56,7 @@ class ExpectColumnPairValuesAToBeGreaterThanB(TableExpectation):
         "requirements": [],
     }
 
-    metric_dependencies = ("column_a_greater_than_b",)
+    map_metric = "column_pair_values.a_greater_than_b"
     success_keys = (
         "column_A",
         "column_B",
@@ -80,12 +64,11 @@ class ExpectColumnPairValuesAToBeGreaterThanB(TableExpectation):
         "parse_strings_as_datetimes",
         "allow_cross_type_comparisons",
         "or_equal",
+        "mostly",
     )
 
     default_kwarg_values = {
-        "column_A": None,
-        "column_B": None,
-        "or_equal": None,
+        "mostly": 1.0,
         "parse_strings_as_datetimes": False,
         "allow_cross_type_comparisons": None,
         "ignore_row_if": "both_values_are_missing",
@@ -93,7 +76,7 @@ class ExpectColumnPairValuesAToBeGreaterThanB(TableExpectation):
         "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
         "result_format": "BASIC",
         "include_config": True,
-        "catch_exceptions": True,
+        "catch_exceptions": False,
     }
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
