@@ -1,15 +1,6 @@
-from typing import Dict, List, Optional, Union
+from typing import Optional
 
-import numpy as np
-import pandas as pd
-
-from great_expectations.core.batch import Batch
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
-from great_expectations.execution_engine import (
-    ExecutionEngine,
-    PandasExecutionEngine,
-    SparkDFExecutionEngine,
-)
 from great_expectations.expectations.util import render_evaluation_parameter_string
 
 from ...render.renderer.renderer import renderer
@@ -19,15 +10,10 @@ from ...render.util import (
     parse_row_condition_string_pandas_engine,
     substitute_none_for_missing,
 )
-from ..expectation import InvalidExpectationConfigurationError, TableExpectation
-
-try:
-    import sqlalchemy as sa
-except ImportError:
-    pass
+from ..expectation import ColumnPairMapExpectation, InvalidExpectationConfigurationError
 
 
-class ExpectColumnPairValuesToBeEqual(TableExpectation):
+class ExpectColumnPairValuesToBeEqual(ColumnPairMapExpectation):
     """
     Expect the values in column A to be the same as column B.
 
@@ -41,16 +27,12 @@ class ExpectColumnPairValuesToBeEqual(TableExpectation):
     Other Parameters:
         result_format (str or None): \
             Which output mode to use: `BOOLEAN_ONLY`, `BASIC`, `COMPLETE`, or `SUMMARY`.
-            For more detail, see :ref:`result_format <result_format>`.
         include_config (boolean): \
             If True, then include the expectation config as part of the result object. \
-            For more detail, see :ref:`include_config`.
         catch_exceptions (boolean or None): \
             If True, then catch exceptions and include them as part of the result object. \
-            For more detail, see :ref:`catch_exceptions`.
         meta (dict or None): \
-            A JSON-serializable dictionary (nesting allowed) that will be included in the output without \
-            modification. For more detail, see :ref:`meta`.
+            A JSON-serializable dictionary (nesting allowed) that will be included in the output without modification.
 
     Returns:
         An ExpectationSuiteValidationResult
@@ -72,24 +54,22 @@ class ExpectColumnPairValuesToBeEqual(TableExpectation):
         "requirements": [],
     }
 
-    metric_dependencies = ("equal_columns",)
+    map_metric = "column_pair_values.equal"
     success_keys = (
         "column_A",
         "column_B",
         "ignore_row_if",
+        "mostly",
     )
 
     default_kwarg_values = {
-        "column_A": None,
-        "column_B": None,
-        "ignore_row_if": "both_values_are_missing",
         "row_condition": None,
         "condition_parser": None,  # we expect this to be explicitly set whenever a row_condition is passed
-        "mostly": 1,
-        "parse_strings_as_datetimes": None,
+        "ignore_row_if": "both_values_are_missing",
+        "mostly": 1.0,
         "result_format": "BASIC",
         "include_config": True,
-        "catch_exceptions": True,
+        "catch_exceptions": False,
     }
 
     def validate_configuration(self, configuration: Optional[ExpectationConfiguration]):
