@@ -12,8 +12,8 @@ from great_expectations.execution_engine.execution_engine import MetricDomainTyp
 from great_expectations.execution_engine.sqlalchemy_execution_engine import (
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.expectations.metrics.column_aggregate_metric import (
-    ColumnMetricProvider,
+from great_expectations.expectations.metrics.column_aggregate_metric_provider import (
+    ColumnAggregateMetricProvider,
     column_aggregate_partial,
     column_aggregate_value,
 )
@@ -21,7 +21,7 @@ from great_expectations.expectations.metrics.metric_provider import metric_value
 from great_expectations.validator.validation_graph import MetricConfiguration
 
 
-class ColumnPartition(ColumnMetricProvider):
+class ColumnPartition(ColumnAggregateMetricProvider):
     metric_name = "column.partition"
     value_keys = ("bins", "n_bins", "allow_relative_error")
     default_kwarg_values = {
