@@ -7,8 +7,8 @@ from great_expectations.execution_engine import (
 from great_expectations.execution_engine.sqlalchemy_execution_engine import (
     SqlAlchemyExecutionEngine,
 )
-from great_expectations.expectations.metrics.column_aggregate_metric import (
-    ColumnMetricProvider,
+from great_expectations.expectations.metrics.column_aggregate_metric_provider import (
+    ColumnAggregateMetricProvider,
     column_aggregate_partial,
     column_aggregate_value,
 )
@@ -26,7 +26,7 @@ except ImportError as e:
 from great_expectations.expectations.metrics.import_manager import F, sa
 
 
-class ColumnStandardDeviation(ColumnMetricProvider):
+class ColumnStandardDeviation(ColumnAggregateMetricProvider):
     """MetricProvider Class for Aggregate Standard Deviation metric"""
 
     metric_name = "column.standard_deviation"
