@@ -2,10 +2,10 @@ import json
 
 import pytest
 
-from great_expectations.core import expectationSuiteSchema
 from great_expectations.data_context import BaseDataContext
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.exceptions import DataContextError
+from great_expectations.self_check.util import expectationSuiteSchema
 
 
 @pytest.fixture()
@@ -14,7 +14,9 @@ def parameterized_expectation_suite():
         __file__,
         "../test_fixtures/expectation_suites/parameterized_expression_expectation_suite_fixture.json",
     )
-    with open(fixture_path, "r",) as suite:
+    with open(
+        fixture_path,
+    ) as suite:
         return expectationSuiteSchema.load(json.load(suite))
 
 
@@ -79,7 +81,9 @@ def test_run_validation_operator_raises_error_if_non_batches_are_passed_in_list(
             validation_operator_name="store_val_res_and_extract_eval_params",
             assets_to_validate=["foo"],
         )
-    assert e.value.message == "Batches are required to be of type DataAsset"
+    assert (
+        e.value.message == "Batches are required to be of type DataAsset or Validator"
+    )
 
 
 def test_run_validation_operator_raises_error_if_no_matching_validation_operator_is_found(
@@ -88,7 +92,8 @@ def test_run_validation_operator_raises_error_if_no_matching_validation_operator
     context = validation_operators_data_context
     with pytest.raises(DataContextError) as e:
         context.run_validation_operator(
-            validation_operator_name="blarg", assets_to_validate=[(1, 2)],
+            validation_operator_name="blarg",
+            assets_to_validate=[(1, 2)],
         )
     assert (
         e.value.message
