@@ -641,7 +641,7 @@ def test_init_on_existing_project_with_datasource_with_no_suite_create_one(
     datasource = all_datasources[0] if all_datasources else None
 
     # create a sqlalchemy engine using the URL of existing datasource
-    engine = sa.create_engine(datasource.get("credentials", dict()).get("url"))
+    engine = sa.create_engine(datasource.get("credentials", {}).get("url"))
     inspector = sa.inspect(engine)
 
     # get the default schema and table for testing
