@@ -5,7 +5,9 @@ import pytest
 
 import great_expectations as ge
 import great_expectations.render as render
-from great_expectations.core import ExpectationSuiteValidationResult
+from great_expectations.core.expectation_validation_result import (
+    ExpectationSuiteValidationResult,
+)
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.render.renderer import ProfilingResultsPageRenderer
 from great_expectations.render.types import (
@@ -22,13 +24,13 @@ from great_expectations.render.view import DefaultJinjaPageView
 
 @pytest.fixture()
 def validation_results():
-    with open("./tests/test_sets/expected_cli_results_default.json", "r") as infile:
+    with open("./tests/test_sets/expected_cli_results_default.json") as infile:
         return json.load(infile, object_pairs_hook=OrderedDict)
 
 
 @pytest.fixture()
 def expectations():
-    with open("./tests/test_sets/titanic_expectations.json", "r") as infile:
+    with open("./tests/test_sets/titanic_expectations.json") as infile:
         return json.load(infile, object_pairs_hook=OrderedDict)
 
 
@@ -75,7 +77,10 @@ def test_render_section_page():
             "section_name": None,
             "content_blocks": [
                 RenderedHeaderContent(
-                    **{"content_block_type": "header", "header": "Overview",}
+                    **{
+                        "content_block_type": "header",
+                        "header": "Overview",
+                    }
                 ),
                 RenderedTableContent(
                     **{
@@ -97,7 +102,10 @@ def test_render_section_page():
     ).to_json_dict()
 
     rendered_doc = ge.render.view.view.DefaultJinjaSectionView().render(
-        {"section": section, "section_loop": {"index": 1},}
+        {
+            "section": section,
+            "section_loop": {"index": 1},
+        }
     )  # .replace(" ", "").replace("\t", "").replace("\n", "")
 
     print(rendered_doc)
@@ -157,7 +165,10 @@ def test_rendering_components_without_section_loop_index():
         }
     ).to_json_dict()
     rendered_doc = ge.render.view.view.DefaultJinjaComponentView().render(
-        {"content_block": header_component_content, "content_block_loop": {"index": 2},}
+        {
+            "content_block": header_component_content,
+            "content_block_loop": {"index": 2},
+        }
     )
     print(rendered_doc)
     rendered_doc = rendered_doc.replace(" ", "").replace("\t", "").replace("\n", "")
@@ -178,7 +189,9 @@ def test_rendering_components_without_section_loop_index():
     )
 
     rendered_doc = ge.render.view.view.DefaultJinjaComponentView().render(
-        {"content_block": header_component_content,}
+        {
+            "content_block": header_component_content,
+        }
     )
     print(rendered_doc)
     rendered_doc = rendered_doc.replace(" ", "").replace("\t", "").replace("\n", "")
@@ -199,7 +212,10 @@ def test_rendering_components_without_section_loop_index():
     )
 
     rendered_doc = ge.render.view.view.DefaultJinjaComponentView().render(
-        {"content_block": header_component_content, "section_loop": {"index": 3},}
+        {
+            "content_block": header_component_content,
+            "section_loop": {"index": 3},
+        }
     )
     print(rendered_doc)
     rendered_doc = rendered_doc.replace(" ", "").replace("\t", "").replace("\n", "")
@@ -231,7 +247,11 @@ def test_rendering_components_with_styling():
                     "content_block_type": "string_template",
                     "string_template": {
                         "template": "$var1 $var2 $var3",
-                        "params": {"var1": "AAA", "var2": "BBB", "var3": "CCC",},
+                        "params": {
+                            "var1": "AAA",
+                            "var2": "BBB",
+                            "var3": "CCC",
+                        },
                         "styling": {
                             "default": {"classes": ["x"]},
                             "params": {"var1": {"classes": ["y"]}},
@@ -244,7 +264,11 @@ def test_rendering_components_with_styling():
                     "content_block_type": "string_template",
                     "string_template": {
                         "template": "$var1 $var2 $var3",
-                        "params": {"var1": "aaa", "var2": "bbb", "var3": "ccc",},
+                        "params": {
+                            "var1": "aaa",
+                            "var2": "bbb",
+                            "var3": "ccc",
+                        },
                         "styling": {
                             "default": {"classes": ["xx"]},
                             "params": {"var1": {"classes": ["yy"]}},
@@ -252,7 +276,10 @@ def test_rendering_components_with_styling():
                     },
                 }
             ),
-            "table": [["Mean", "446"], ["Minimum", "1"],],
+            "table": [
+                ["Mean", "446"],
+                ["Minimum", "1"],
+            ],
             "styling": {
                 "classes": ["root_foo"],
                 "styles": {"root": "bar"},
@@ -368,8 +395,13 @@ def test_render_table_component():
         **{
             "content_block_type": "table",
             "header": "Overview",
-            "table": [["Mean", "446"], ["Minimum", "1"],],
-            "styling": {"classes": ["col-4"],},
+            "table": [
+                ["Mean", "446"],
+                ["Minimum", "1"],
+            ],
+            "styling": {
+                "classes": ["col-4"],
+            },
         }
     ).to_json_dict()
     rendered_doc = ge.render.view.view.DefaultJinjaComponentView().render(
