@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import json
 import os
 from collections import OrderedDict
@@ -6,7 +5,8 @@ from collections import OrderedDict
 import mistune
 import pytest
 
-from great_expectations.core import ExpectationConfiguration, ExpectationSuite
+from great_expectations.core.expectation_configuration import ExpectationConfiguration
+from great_expectations.core.expectation_suite import ExpectationSuite
 from great_expectations.data_context.util import file_relative_path
 from great_expectations.render.renderer import (
     ExpectationSuitePageRenderer,
@@ -213,9 +213,11 @@ def test_ValidationResultsPageRenderer_render_validation_header(
         "subheader": {
             "content_block_type": "string_template",
             "string_template": {
-                "template": "${suite_title} ${expectation_suite_name}\n${status_title} ${html_success_icon} ${success}",
+                "template": "${suite_title} ${expectation_suite_name}\n ${data_asset} ${data_asset_name}\n ${status_title} ${html_success_icon} ${success}",
                 "params": {
                     "suite_title": "Expectation Suite:",
+                    "data_asset": "Data asset:",
+                    "data_asset_name": None,
                     "status_title": "Status:",
                     "expectation_suite_name": "default",
                     "success": "Failed",
@@ -237,8 +239,9 @@ def test_ValidationResultsPageRenderer_render_validation_header(
             },
         },
     }
+    import pprint
 
-    # print(validation_header)
+    pprint.pprint(validation_header)
     assert validation_header == expected_validation_header
 
 
@@ -483,7 +486,7 @@ def ValidationResultsPageRenderer_render_with_run_info_at_end():
         __file__,
         "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_end.json",
     )
-    with open(fixture_filename, "r") as infile:
+    with open(fixture_filename) as infile:
         rendered_validation_results = json.load(infile)
         return rendered_validation_results
 
@@ -499,13 +502,14 @@ def ValidationResultsPageRenderer_render_with_run_info_at_start():
         __file__,
         "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_start.json",
     )
-    with open(fixture_filename, "r") as infile:
+    with open(fixture_filename) as infile:
         rendered_validation_results = json.load(infile)
         return rendered_validation_results
 
 
 def test_snapshot_ValidationResultsPageRenderer_render_with_run_info_at_end(
-    titanic_profiled_evrs_1, ValidationResultsPageRenderer_render_with_run_info_at_end,
+    titanic_profiled_evrs_1,
+    ValidationResultsPageRenderer_render_with_run_info_at_end,
 ):
     validation_results_page_renderer = ValidationResultsPageRenderer(
         run_info_at_end=True
@@ -513,10 +517,12 @@ def test_snapshot_ValidationResultsPageRenderer_render_with_run_info_at_end(
     rendered_validation_results = validation_results_page_renderer.render(
         titanic_profiled_evrs_1
     ).to_json_dict()
-    print(rendered_validation_results)
-    # with open(file_relative_path(__file__, "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_end.json"), "w") as f:
-    #     json.dump(rendered_validation_results, f, indent=2)
+    import pprint
 
+    pprint.pprint(rendered_validation_results["sections"])
+    # with open(file_relative_path(__file__, "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_end_nc.json"), "w") as f:
+    #     json.dump(rendered_validation_results, f, indent=2)
+    pprint.pprint(ValidationResultsPageRenderer_render_with_run_info_at_end)
     assert (
         rendered_validation_results
         == ValidationResultsPageRenderer_render_with_run_info_at_end
@@ -534,7 +540,7 @@ def test_snapshot_ValidationResultsPageRenderer_render_with_run_info_at_start(
         titanic_profiled_evrs_1
     ).to_json_dict()
     print(rendered_validation_results)
-    # with open(file_relative_path(__file__, "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_start.json"), "w") as f:
+    # with open(file_relative_path(__file__, "./fixtures/ValidationResultsPageRenderer_render_with_run_info_at_start_nc.json"), "w") as f:
     #     json.dump(rendered_validation_results, f, indent=2)
 
     assert (
