@@ -188,6 +188,100 @@ def test_ValidationResultsTableContentBlockRenderer_get_content_block_fn(evr_suc
     assert content_block_fn_output == content_block_fn_expected_output
 
 
+def test_ValidationResultsTableContentBlockRenderer_get_content_block_fn_with_v2_api_style_custom_rendering():
+    """Test backwards support for custom expectation rendering with the V2 API as described at
+    https://docs.greatexpectations.io/en/latest/reference/spare_parts/data_docs_reference.html#customizing-data-docs.
+    """
+
+    custom_expectation_template = "custom_expectation_template"
+    custom_expectation_observed_value = "custom_expectation_observed_value"
+
+    class ValidationResultsTableContentBlockRendererWithV2ApiStyleCustomExpectations(
+        ValidationResultsTableContentBlockRenderer
+    ):
+        @classmethod
+        def expect_custom_expectation_written_in_v2_api_style(
+            cls, expectation, styling=None, include_column_name: bool = True
+        ):
+            return [
+                RenderedStringTemplateContent(
+                    content_block_type="string_template",
+                    string_template={
+                        "template": custom_expectation_template,
+                        "params": expectation.kwargs,
+                        "styling": styling,
+                    },
+                )
+            ]
+
+    evr = ExpectationValidationResult(
+        success=True,
+        result={
+            "observed_value": custom_expectation_observed_value,
+        },
+        exception_info={
+            "raised_exception": False,
+            "exception_message": None,
+            "exception_traceback": None,
+        },
+        expectation_config=ExpectationConfiguration(
+            expectation_type="expect_custom_expectation",
+            kwargs={"column": "a_column_name", "result_format": "SUMMARY"},
+        ),
+    )
+
+    content_block_fn = ValidationResultsTableContentBlockRendererWithV2ApiStyleCustomExpectations._get_content_block_fn(
+        "expect_custom_expectation_written_in_v2_api_style"
+    )
+    content_block_fn_output = content_block_fn(result=evr)
+
+    content_block_fn_expected_output = [
+        [
+            RenderedStringTemplateContent(
+                **{
+                    "content_block_type": "string_template",
+                    "string_template": {
+                        "template": "$icon",
+                        "params": {"icon": "", "markdown_status_icon": "✅"},
+                        "styling": {
+                            "params": {
+                                "icon": {
+                                    "classes": [
+                                        "fas",
+                                        "fa-check-circle",
+                                        "text-success",
+                                    ],
+                                    "tag": "i",
+                                }
+                            }
+                        },
+                    },
+                    "styling": {
+                        "parent": {
+                            "classes": ["hide-succeeded-validation-target-child"]
+                        }
+                    },
+                }
+            ),
+            RenderedStringTemplateContent(
+                **{
+                    "content_block_type": "string_template",
+                    "string_template": {
+                        "template": custom_expectation_template,
+                        "params": {
+                            "column": "a_column_name",
+                            "result_format": "SUMMARY",
+                        },
+                        "styling": None,
+                    },
+                }
+            ),
+            custom_expectation_observed_value,
+        ]
+    ]
+    assert content_block_fn_output == content_block_fn_expected_output
+
+
 def test_ValidationResultsTableContentBlockRenderer_get_observed_value(evr_success):
     evr_no_result_key = ExpectationValidationResult(
         success=True,
